=======
History
=======

Unreleased
----------

0.3.0 (2019-01-07)
------------------

* Improve code readability
* Add --version argument
* Add `Black`_ to project
* Add GitHub actions for testing
* Remove travis-ci integration
* Set prog in ArgumentParser to lineno
* Fix lineno couldn't be executed as a package by calling `python -m lineno ...`

0.2.1 (2017-10-24)
------------------

* Fix README.rst documentation

0.2.0 (2017-10-24)
------------------

* Add -l/--line-number argument instead of requiring that the line number sequence is the first argument.

0.1.0 (2017-07-01)
------------------

* First release on PyPI.

.. _Black: https://github.com/ambv/black
